// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `vaem` vocabulary
//!
//! This module requires `ns-vaem` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|vaem|
//! |**Namespace base IRI**|<http://www.linkedmodel.org/schema/vaem#>|
//! |**Description**||
//! |**Is defined by**|<http://www.linkedmodel.org/schema/vaem#>|
//!

use crate::namespace;

namespace!(
    "http://www.linkedmodel.org/schema/vaem#",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Aspect Dimension`: 
    Aspect, "Aspect",
    /// `CatalogEntry`: 
    CatalogEntry, "CatalogEntry",
    /// `Collection graph`: 
    CollectionGraph, "CollectionGraph",
    /// `Constraints graph`: 
    ConstraintsGraph, "ConstraintsGraph",
    /// `Controllers graph`: 
    ControllersGraph, "ControllersGraph",
    /// `Curation graph`: 
    CurationGraph, "CurationGraph",
    /// `Data graph`: 
    DataGraph, "DataGraph",
    /// `Domain`: 
    Dimension, "Dimension",
    /// `Discipline Dimension`: 
    Discipline, "Discipline",
    /// `Documentation graph`: 
    DocumentationGraph, "DocumentationGraph",
    /// `Domain Dimension`: 
    Domain, "Domain",
    /// `Functions graph`: 
    FunctionsGraph, "FunctionsGraph",
    /// `VAEM Schema Version 2.0 Metadata`: 
    GMD_VAEM, "GMD_VAEM",
    /// `Graph Metadata`: 
    GraphMetaData, "GraphMetaData",
    /// `Graph role`: 
    GraphRole, "GraphRole",
    /// `Link Set graph`: 
    LinkSetGraph, "LinkSetGraph",
    /// `Mapping graph`: 
    MappingGraph, "MappingGraph",
    /// `Party`: 
    Party, "Party",
    /// `Proxy graph`: 
    ProxyGraph, "ProxyGraph",
    /// `Rules Graph`: 
    RulesGraph, "RulesGraph",
    /// `Schema graph`: 
    SchemaGraph, "SchemaGraph",
    /// `Script graph`: 
    ScriptGraph, "ScriptGraph",
    /// `TopQuadrant`: 
    TopQuadrant, "TopQuadrant",
    /// `Transforms graph`: 
    TransformsGraph, "TransformsGraph",
    /// `View graph`: 
    ViewGraph, "ViewGraph",
    /// `ViewpointDimension`: 
    Viewpoint, "Viewpoint",
    /// `Vocabulary graph`: 
    VocabularyGraph, "VocabularyGraph",
    /// `abbreviation`: 
    abbreviation, "abbreviation",
    /// `acronym`: 
    acronym, "acronym",
    /// `definition`: 
    comment, "comment",
    /// `date`: 
    date, "date",
    /// `dateCreated`: 
    dateCreated, "dateCreated",
    /// `description`: 
    description, "description",
    /// `file prefix`: 
    filePrefix, "filePrefix",
    /// `has aspect `: 
    hasAspect, "hasAspect",
    /// `has dimension`: 
    hasDimension, "hasDimension",
    /// `has discipline`: 
    hasDiscipline, "hasDiscipline",
    /// `has domain`: 
    hasDomain, "hasDomain",
    /// `hasGraphMetadata`: 
    hasGraphMetadata, "hasGraphMetadata",
    /// `has graph role`: 
    hasGraphRole, "hasGraphRole",
    /// `has identifier`: 
    hasIdentifier, "hasIdentifier",
    /// `has license type`: 
    hasLicenseType, "hasLicenseType",
    /// `has metadata`: 
    hasMetadata, "hasMetadata",
    /// `has owner`: 
    hasOwner, "hasOwner",
    /// `has steward`: 
    hasSteward, "hasSteward",
    /// `has viewpoint`: 
    hasViewpoint, "hasViewpoint",
    /// `id`: 
    id, "id",
    /// `idString`: 
    idString, "idString",
    /// `intent`: 
    intent, "intent",
    /// `isDefinedBy`: 
    isElaboratedIn, "isElaboratedIn",
    /// `lastUpdated`: 
    lastUpdated, "lastUpdated",
    /// `latest published version`: 
    latestPublishedVersion, "latestPublishedVersion",
    /// `logo`: 
    logo, "logo",
    /// `name`: 
    name, "name",
    /// `namespace`: 
    namespace, "namespace",
    /// `namespace prefix`: 
    namespacePrefix, "namespacePrefix",
    /// `ownedBy`: 
    ownedBy, "ownedBy",
    /// `owner`: 
    owner, "owner",
    /// `owningParty`: 
    owningParty, "owningParty",
    /// `previous published version`: 
    previousPublishedVersion, "previousPublishedVersion",
    /// `rationale`: 
    rationale, "rationale",
    /// `RDF/XML file URL`: 
    rdfxmlFileURL, "rdfxmlFileURL",
    /// `reifiable by`: 
    reifiableBy, "reifiableBy",
    /// `release date`: 
    releaseDate, "releaseDate",
    /// `revision`: 
    revision, "revision",
    /// `specificity`: 
    specificity, "specificity",
    /// `title`: 
    title, "title",
    /// `todo`: 
    todo, "todo",
    /// `turtle file URL`: 
    turtleFileURL, "turtleFileURL",
    /// `url`: 
    url, "url",
    /// `uses non-imported resource`: 
    usesNonImportedResource, "usesNonImportedResource",
    /// `with attribution to`: 
    withAttributionTo, "withAttributionTo"
);
